@@ -702,22 +702,91 @@ def test_parameter_line_without_colon_keyword_only(parse_google):
     assert "Empty" in warnings[1]
 
 
-# TODO: possible feature
-# def test_extra_parameter(parse_google):
-#     """Warn on extra parameter in docstring.
-#
-#     Parameters:
-#         parse_google: Fixture parser.
-#     """
-#     docstring = """
-#         Parameters:
-#             x: Integer.
-#             y: Integer.
-#     """
+def test_warn_about_unknown_parameters(parse_google):
+    """Warn about unknown parameters in "Parameters" sections.
 
-#     sections, warnings = parse_google(docstring)
-#     assert len(sections) == 1
-#     assert len(warnings) == 2
+    Parameters:
+        parse_google: Fixture parser.
+    """
+    docstring = """
+        Parameters:
+            x (int): Integer.
+            y (int): Integer.
+    """
+
+    _, warnings = parse_google(
+        docstring,
+        parent=Function(
+            "func",
+            parameters=Parameters(
+                Parameter("a"),
+                Parameter("y"),
+            ),
+        ),
+    )
+    assert len(warnings) == 1
+    assert "'x' does not appear in the function signature" in warnings[0]
+
+
+def test_never_warn_about_unknown_other_parameters(parse_google):
+    """Never warn about unknown parameters in "Other parameters" sections.
+
+    Parameters:
+        parse_google: Fixture parser.
+    """
+    docstring = """
+        Other Parameters:
+            x (int): Integer.
+            z (int): Integer.
+    """
+
+    _, warnings = parse_google(
+        docstring,
+        parent=Function(
+            "func",
+            parameters=Parameters(
+                Parameter("a"),
+                Parameter("y"),
+            ),
+        ),
+    )
+    assert not warnings
+
+
+def test_unknown_params_scan_doesnt_crash_without_parameters(parse_google):
+    """Assert we don't crash when parsing parameters sections and parent object does not have parameters.
+
+    Parameters:
+        parse_google: Fixture parser.
+    """
+    docstring = """
+        Parameters:
+            this (str): This.
+            that (str): That.
+    """
+
+    _, warnings = parse_google(docstring, parent=Module("mod"))
+    assert not warnings
+
+
+def test_class_uses_init_parameters(parse_google):
+    """Assert we use the `__init__` parameters when parsing classes' parameters sections.
+
+    Parameters:
+        parse_google: Fixture parser.
+    """
+    docstring = """
+        Parameters:
+            x: X value.
+    """
+    parent = Class("c")
+    parent["__init__"] = Function("__init__", parameters=Parameters(Parameter("x", annotation="int")))
+    sections, warnings = parse_google(docstring, parent=parent)
+    assert not warnings
+    argx = sections[0].value[0]
+    assert argx.name == "x"
+    assert argx.annotation == "int"
+    assert argx.description == "X value."
 
 
 # TODO: possible feature
@@ -947,6 +1016,26 @@ def test_handle_false_admonitions_correctly(parse_google, docstring):
     assert not warnings
 
 
+def test_dont_insert_admonition_before_current_section(parse_google):
+    """Check that admonitions are inserted at the right place.
+
+    Parameters:
+        parse_google: Fixture parser.
+    """
+    docstring = """
+        Summary.
+
+        Short description.
+
+        Info:
+            Something useful.
+    """
+    sections, _ = parse_google(docstring)
+    assert len(sections) == 2
+    assert sections[0].kind is DocstringSectionKind.text
+    assert sections[1].kind is DocstringSectionKind.admonition
+
+
 @pytest.mark.parametrize(
     "docstring",
     [
